Fetch Champion Data Team Stats for Competition
Source:R/fetch_player_stats.R
fetch_team_stats_championdata.RdFetches team stats for the given Champion Data competition ID. If round is provided, filters fixtures to that round.
R/fetch_player_stats.R
fetch_team_stats_championdata.RdFetches team stats for the given Champion Data competition ID. If round is provided, filters fixtures to that round.