Learn R Programming

nrlR (version 0.1.2)

fetch_results: Fetch Rugby League Match Results

Description

Main wrapper to fetch match results for one or more seasons.

Usage

fetch_results(
  seasons,
  league = c("nrl", "super_league", "championship", "league_one", "womens_super_league",
    "qld_cup", "nsw_cup", "state_of_origin", "challenge_cup", "1895_cup"),
  source = c("rugbyleagueproject")
)

Value

A tibble of match results with parsed date and round.

Arguments

seasons

Integer vector. One or more seasons to fetch (1998 or later).

league

Character. League name. See options.

source

Character. Data source; only "rugbyleagueproject" currently supported.