Main wrapper to fetch match results for one or more seasons.
fetch_results(
seasons,
league = c("nrl", "super_league", "championship", "league_one", "womens_super_league",
"qld_cup", "nsw_cup", "state_of_origin", "challenge_cup", "1895_cup"),
source = c("rugbyleagueproject")
)A tibble of match results with parsed date and round.
Integer vector. One or more seasons to fetch (1998 or later).
Character. League name. See options.
Character. Data source; only "rugbyleagueproject" currently supported.