Learn R Programming

nrlR (version 0.1.2)

fetch_results_rugbyproject: Fetch Rugby League Match Results from Rugby League Project

Description

Fetch Rugby League Match Results from Rugby League Project

Usage

fetch_results_rugbyproject(seasons, league)

Value

A tibble of match results with parsed date, aligned to weekday, and round.

Arguments

seasons

Integer vector. One or more seasons to fetch (1998 or later).

league

Character. League name. See options.